scipy.signal.lti
================

.. currentmodule:: scipy.signal

.. autoclass:: lti

   

   .. HACK
      .. autosummary::
         :toctree:
      
         lti.__init__
         lti.impulse
         lti.output
         lti.step



   

